import { __assign } from "tslib";
/**
 * External dependencies
 */
import React, { useState, useEffect } from 'react';
var defaultExperimentOptions = {
    isEligible: true,
};
export default function createExPlatClientReactHelpers(exPlatClient) {
    var useExperiment = function (experimentName, providedOptions) {
        if (providedOptions === void 0) { providedOptions = {}; }
        var options = __assign(__assign({}, defaultExperimentOptions), providedOptions);
        var previousExperimentName = useState(experimentName)[0];
        var _a = useState([
            true,
            null,
        ]), state = _a[0], setState = _a[1];
        useEffect(function () {
            var isSubscribed = true;
            if (options.isEligible) {
                exPlatClient.loadExperimentAssignment(experimentName).then(function (experimentAssignment) {
                    if (isSubscribed) {
                        setState([false, experimentAssignment]);
                    }
                });
            }
            return function () {
                isSubscribed = false;
            };
        }, [experimentName, options.isEligible]);
        if (experimentName !== previousExperimentName &&
            !previousExperimentName.startsWith('explat_test')) {
            exPlatClient.config.logError({
                message: '[ExPlat] useExperiment: experimentName should never change between renders!',
            });
        }
        if (!options.isEligible) {
            return [false, null];
        }
        return state;
    };
    var Experiment = function (_a) {
        var defaultExperience = _a.defaultExperience, treatmentExperience = _a.treatmentExperience, loadingExperience = _a.loadingExperience, experimentName = _a.name, options = _a.options;
        var _b = useExperiment(experimentName, options), isLoading = _b[0], experimentAssignment = _b[1];
        if (isLoading) {
            return React.createElement(React.Fragment, null, loadingExperience);
        }
        else if (!(experimentAssignment === null || experimentAssignment === void 0 ? void 0 : experimentAssignment.variationName)) {
            return React.createElement(React.Fragment, null, defaultExperience);
        }
        return React.createElement(React.Fragment, null, treatmentExperience);
    };
    var ProvideExperimentData = function (_a) {
        var children = _a.children, experimentName = _a.name, options = _a.options;
        var _b = useExperiment(experimentName, options), isLoading = _b[0], experimentAssignment = _b[1];
        return children(isLoading, experimentAssignment);
    };
    return {
        useExperiment: useExperiment,
        Experiment: Experiment,
        ProvideExperimentData: ProvideExperimentData,
    };
}
