/**
 * External dependencies
 */
import React from 'react';
/**
 * WordPress dependencies
 */
import type { ExPlatClient, ExperimentAssignment } from '@automattic/explat-client';
interface ExperimentOptions {
    /**
     * Determines whether a participant is currenlty eligible for an assignment.
     * - Only loads the experimentAssignment if isEligible is true.
     * - Only returns the experimentAssignment if isEligible is true.
     */
    isEligible?: boolean;
}
interface ExPlatClientReactHelpers {
    /**
     * An ExPlat useExperiment hook.
     *
     * NOTE: Doesn't obey ExperimentAssignment TTL in order to keep stable UX.
     *
     * @returns [isExperimentAssignmentLoading, ExperimentAssignment | null]
     */
    useExperiment: (experimentName: string, options?: ExperimentOptions) => [boolean, ExperimentAssignment | null];
    /**
     * Experiment component, safest and simplest, should be first choice if usable.
     */
    Experiment: (props: {
        name: string;
        defaultExperience: React.ReactNode;
        treatmentExperience: React.ReactNode;
        loadingExperience: React.ReactNode;
        options?: ExperimentOptions;
    }) => JSX.Element;
    /**
     * Inject experiment data into a child component.
     * Use when hooks aren't available.
     */
    ProvideExperimentData: (props: {
        children: (isLoading: boolean, experimentAssignment: ExperimentAssignment | null) => JSX.Element;
        name: string;
        options?: ExperimentOptions;
    }) => JSX.Element;
}
export default function createExPlatClientReactHelpers(exPlatClient: ExPlatClient): ExPlatClientReactHelpers;
export {};
